==> libopenshot-0.3.2-x86_64-2ponce.txz: usr/doc/libopenshot-0.3.2/API/search/all_13.js <==
var searchData=
[
  ['q_5ffactor_0',['q_factor',['../classopenshot_1_1ParametricEQ.html#a2c59a8b776b6ace63766d30a0f974206',1,'openshot::ParametricEQ']]],
  ['qimage2magick_1',['QImage2Magick',['../namespaceopenshot.html#aa2b4266d8fdcf7637493931e70ddaf86',1,'openshot']]],
  ['qimage2mat_2',['Qimage2mat',['../classopenshot_1_1Frame.html#a482f6d41d79c4ac380a0b0bbe048e960',1,'openshot::Frame']]],
  ['qt_205_20libqt5_3',['Qt 5 libqt5',['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-LINUX.html#autotoc_md22',1,'Qt 5 (libqt5)'],['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-MAC.html#autotoc_md50',1,'Qt 5 (libqt5)'],['../md__2tmp_2sbopkg_8NNCQoQ_2libopenshot-0_83_82_2doc_2INSTALL-WINDOWS.html#autotoc_md78',1,'Qt 5 (libqt5)']]],
  ['qt_5fversion_5fstr_4',['QT_VERSION_STR',['../OpenShotVersion_8h.html#aa261ecc8dfc4a1bdd1ef9ce16008f91c',1,'OpenShotVersion.h']]],
  ['qthtmlreader_5',['QtHtmlReader',['../classopenshot_1_1QtHtmlReader.html',1,'openshot::QtHtmlReader'],['../classopenshot_1_1QtHtmlReader.html#aa20d7610bc19af5127d1a94f6d0e38a0',1,'openshot::QtHtmlReader::QtHtmlReader()'],['../classopenshot_1_1QtHtmlReader.html#aac00476e1572e7cc180c0b7764e2422b',1,'openshot::QtHtmlReader::QtHtmlReader(int width, int height, int x_offset, int y_offset, GravityType gravity, std::string html, std::string css, std::string background_color)']]],
  ['qthtmlreader_2ecpp_6',['QtHtmlReader.cpp',['../QtHtmlReader_8cpp.html',1,'']]],
  ['qthtmlreader_2eh_7',['QtHtmlReader.h',['../QtHtmlReader_8h.html',1,'']]],
  ['qtimagereader_8',['QtImageReader',['../classopenshot_1_1QtImageReader.html',1,'openshot::QtImageReader'],['../classopenshot_1_1QtImageReader.html#a316b33b7d2506e803c8d0111bc43c687',1,'openshot::QtImageReader::QtImageReader()']]],
  ['qtimagereader_2ecpp_9',['QtImageReader.cpp',['../QtImageReader_8cpp.html',1,'']]],
  ['qtimagereader_2eh_10',['QtImageReader.h',['../QtImageReader_8h.html',1,'']]],
  ['qtplayer_11',['QtPlayer',['../classopenshot_1_1QtPlayer.html',1,'openshot::QtPlayer'],['../classopenshot_1_1AudioPlaybackThread.html#a5d2956dc013a5d7c9cd2057385221652',1,'openshot::AudioPlaybackThread::QtPlayer'],['../classopenshot_1_1PlayerPrivate.html#a5d2956dc013a5d7c9cd2057385221652',1,'openshot::PlayerPrivate::QtPlayer'],['../classopenshot_1_1VideoCacheThread.html#a5d2956dc013a5d7c9cd2057385221652',1,'openshot::VideoCacheThread::QtPlayer'],['../classopenshot_1_1VideoPlaybackThread.html#a5d2956dc013a5d7c9cd2057385221652',1,'openshot::VideoPlaybackThread::QtPlayer'],['../classopenshot_1_1QtPlayer.html#a6a88a612e263a7ed8128baae5b8c7870',1,'openshot::QtPlayer::QtPlayer()'],['../classopenshot_1_1QtPlayer.html#aa94049f262cf7874028dc8b1fc18e244',1,'openshot::QtPlayer::QtPlayer(openshot::RendererBase *rb)']]],
  ['qtplayer_2ecpp_12',['QtPlayer.cpp',['../QtPlayer_8cpp.html',1,'']]],
  ['qtplayer_2eh_13',['QtPlayer.h',['../QtPlayer_8h.html',1,'']]],
  ['qttextreader_14',['QtTextReader',['../classopenshot_1_1QtTextReader.html',1,'openshot::QtTextReader'],['../classopenshot_1_1QtTextReader.html#ac50393976d188df410a23abe6ce1aa25',1,'openshot::QtTextReader::QtTextReader()'],['../classopenshot_1_1QtTextReader.html#a69563b5f087be98b569b88a72dedc457',1,'openshot::QtTextReader::QtTextReader(int width, int height, int x_offset, int y_offset, GravityType gravity, std::string text, QFont font, std::string text_color, std::string background_color)']]],
  ['qttextreader_2ecpp_15',['QtTextReader.cpp',['../QtTextReader_8cpp.html',1,'']]],
  ['qttextreader_2eh_16',['QtTextReader.h',['../QtTextReader_8h.html',1,'']]],
  ['qtutilities_2eh_17',['QtUtilities.h',['../QtUtilities_8h.html',1,'']]]
];

==> libopenshot-0.3.3-x86_64-1ponce.txz: usr/doc/libopenshot-0.3.3/API/search/all_13.js <==
var searchData=
[
  ['q_5ffactor_0',['q_factor',['../classopenshot_1_1ParametricEQ.html#a2c59a8b776b6ace63766d30a0f974206',1,'openshot::ParametricEQ']]],
  ['qimage2magick_1',['QImage2Magick',['../namespaceopenshot.html#aa2b4266d8fdcf7637493931e70ddaf86',1,'openshot']]],
  ['qimage2mat_2',['Qimage2mat',['../classopenshot_1_1Frame.html#a482f6d41d79c4ac380a0b0bbe048e960',1,'openshot::Frame']]],
  ['qt_205_20libqt5_3',['Qt 5 libqt5',['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-LINUX.html#autotoc_md22',1,'Qt 5 (libqt5)'],['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-MAC.html#autotoc_md50',1,'Qt 5 (libqt5)'],['../md__2tmp_2sbopkg_8sPtMvf_2libopenshot-0_83_83_2doc_2INSTALL-WINDOWS.html#autotoc_md78',1,'Qt 5 (libqt5)']]],
  ['qt_5fversion_5fstr_4',['QT_VERSION_STR',['../OpenShotVersion_8h.html#aa261ecc8dfc4a1bdd1ef9ce16008f91c',1,'OpenShotVersion.h']]],
  ['qthtmlreader_5',['QtHtmlReader',['../classopenshot_1_1QtHtmlReader.html',1,'openshot::QtHtmlReader'],['../classopenshot_1_1QtHtmlReader.html#aa20d7610bc19af5127d1a94f6d0e38a0',1,'openshot::QtHtmlReader::QtHtmlReader()'],['../classopenshot_1_1QtHtmlReader.html#aac00476e1572e7cc180c0b7764e2422b',1,'openshot::QtHtmlReader::QtHtmlReader(int width, int height, int x_offset, int y_offset, GravityType gravity, std::string html, std::string css, std::string background_color)']]],
  ['qthtmlreader_2ecpp_6',['QtHtmlReader.cpp',['../QtHtmlReader_8cpp.html',1,'']]],
  ['qthtmlreader_2eh_7',['QtHtmlReader.h',['../QtHtmlReader_8h.html',1,'']]],
  ['qtimagereader_8',['QtImageReader',['../classopenshot_1_1QtImageReader.html',1,'openshot::QtImageReader'],['../classopenshot_1_1QtImageReader.html#a316b33b7d2506e803c8d0111bc43c687',1,'openshot::QtImageReader::QtImageReader()']]],
  ['qtimagereader_2ecpp_9',['QtImageReader.cpp',['../QtImageReader_8cpp.html',1,'']]],
  ['qtimagereader_2eh_10',['QtImageReader.h',['../QtImageReader_8h.html',1,'']]],
  ['qtplayer_11',['QtPlayer',['../classopenshot_1_1QtPlayer.html',1,'openshot::QtPlayer'],['../classopenshot_1_1AudioPlaybackThread.html#a5d2956dc013a5d7c9cd2057385221652',1,'openshot::AudioPlaybackThread::QtPlayer'],['../classopenshot_1_1PlayerPrivate.html#a5d2956dc013a5d7c9cd2057385221652',1,'openshot::PlayerPrivate::QtPlayer'],['../classopenshot_1_1VideoCacheThread.html#a5d2956dc013a5d7c9cd2057385221652',1,'openshot::VideoCacheThread::QtPlayer'],['../classopenshot_1_1VideoPlaybackThread.html#a5d2956dc013a5d7c9cd2057385221652',1,'openshot::VideoPlaybackThread::QtPlayer'],['../classopenshot_1_1QtPlayer.html#a6a88a612e263a7ed8128baae5b8c7870',1,'openshot::QtPlayer::QtPlayer()'],['../classopenshot_1_1QtPlayer.html#aa94049f262cf7874028dc8b1fc18e244',1,'openshot::QtPlayer::QtPlayer(openshot::RendererBase *rb)']]],
  ['qtplayer_2ecpp_12',['QtPlayer.cpp',['../QtPlayer_8cpp.html',1,'']]],
  ['qtplayer_2eh_13',['QtPlayer.h',['../QtPlayer_8h.html',1,'']]],
  ['qttextreader_14',['QtTextReader',['../classopenshot_1_1QtTextReader.html',1,'openshot::QtTextReader'],['../classopenshot_1_1QtTextReader.html#ac50393976d188df410a23abe6ce1aa25',1,'openshot::QtTextReader::QtTextReader()'],['../classopenshot_1_1QtTextReader.html#a69563b5f087be98b569b88a72dedc457',1,'openshot::QtTextReader::QtTextReader(int width, int height, int x_offset, int y_offset, GravityType gravity, std::string text, QFont font, std::string text_color, std::string background_color)']]],
  ['qttextreader_2ecpp_15',['QtTextReader.cpp',['../QtTextReader_8cpp.html',1,'']]],
  ['qttextreader_2eh_16',['QtTextReader.h',['../QtTextReader_8h.html',1,'']]],
  ['qtutilities_2eh_17',['QtUtilities.h',['../QtUtilities_8h.html',1,'']]]
];
